#[repr(C)]pub struct OrderRejected {
pub trader_id: TraderId,
pub strategy_id: StrategyId,
pub instrument_id: InstrumentId,
pub client_order_id: ClientOrderId,
pub account_id: AccountId,
pub reason: Ustr,
pub event_id: UUID4,
pub ts_event: UnixNanos,
pub ts_init: UnixNanos,
pub reconciliation: u8,
pub due_post_only: u8,
}Expand description
Represents an event where an order has been rejected by the trading venue.
Fields
trader_id: TraderIdThe trader ID associated with the event.
strategy_id: StrategyIdThe strategy ID associated with the event.
instrument_id: InstrumentIdThe instrument ID associated with the event.
client_order_id: ClientOrderIdThe client order ID associated with the event.
account_id: AccountIdThe account ID associated with the event.
reason: UstrThe reason the order was rejected.
event_id: UUID4The unique identifier for the event.
ts_event: UnixNanosUNIX timestamp (nanoseconds) when the event occurred.
ts_init: UnixNanosUNIX timestamp (nanoseconds) when the event was initialized.
reconciliation: u8If the event was generated during reconciliation.
due_post_only: u8If the order was rejected because it was post-only and would execute immediately as a taker.
Implementations
Sourceimpl OrderRejected
impl OrderRejected
Sourcepub fn new(
trader_id: TraderId,
strategy_id: StrategyId,
instrument_id: InstrumentId,
client_order_id: ClientOrderId,
account_id: AccountId,
reason: Ustr,
event_id: UUID4,
ts_event: UnixNanos,
ts_init: UnixNanos,
reconciliation: bool,
due_post_only: bool,
) -> Self
pub fn new( trader_id: TraderId, strategy_id: StrategyId, instrument_id: InstrumentId, client_order_id: ClientOrderId, account_id: AccountId, reason: Ustr, event_id: UUID4, ts_event: UnixNanos, ts_init: UnixNanos, reconciliation: bool, due_post_only: bool, ) -> Self
Creates a new OrderRejected instance.